<?php
/*
 UWiKiCMS is a lightweight web content management system.
 Copyright (C) 2005, 2006, 2007, 2009, 2013 Christian Mauduit <ufoot@ufoot.org>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public
 License along with this program; if not, write to the Free
 Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA  02110-1301  USA
*/

$this->messages=array
  (
   "about"=>"<a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> version %s by <a href=\"mailto:ufoot@ufoot.org\">U-Foot</a>",

   "title"=>"Title",
   "text"=>"Text",
   "path"=>"Path",
   "order"=>"Order",
   "submit"=>"Submit",
   "create"=>"Create",
   "update"=>"Update",
   "delete"=>"Delete",
   "clear_cache"=>"Clear cache",
   "renum"=>"Renum",
   "all_in_one"=>"All in one page",
   "no_title"=>"No title",
   "doc_created"=>"Document created",
   "doc_updated"=>"Document updated",
   "doc_deleted"=>"Document deleted",
   "cache_cleared"=>"Cache cleared",
   "renum_done"=>"Renum done",
   "confirm_delete"=>"Are you sure you want to delete this document?",
   "image_created"=>"Image created",
   "image_updated"=>"Image updated",
   "image_deleted"=>"Image deleted",
   "confirm_delete_image"=>"Are you sure you want to delete this image?",
   "confirm_clear_cache"=>"Are you sure you want to clear the cache?",
   "confirm_renum"=>"Are you sure you want to perform a renum?",
   "confirm_all_in_one"=>"Are you sure you want to display all contents on one single page? This can take a lot of time...",
   "title_403"=>"403 Forbidden",
   "title_404"=>"404 Not found",
   "title_loginform"=>"Login",
   "title_login"=>"Login",
   "title_logout"=>"Logout",
   "title_createform"=>"New document",
   "title_imagecreateform"=>"New image",
   "title_clearcacheform"=>"Clear cache",
   "title_clearcache"=>"Clear cache",
   "title_renumform"=>"Renum",
   "title_renum"=>"Renum",
   "title_allinoneform"=>"All in one page",
   "title_about"=>"About UWiKiCMS",
   "status"=>"Status",
   "status_0"=>"Public",
   "status_1"=>"Password protected",
   "status_2"=>"Private",
   "status_3"=>"Confidential",
   "rights_0"=>"Copyright &copy; %s %s. Permission is granted to copy, distribute and/or modify this document under the terms of the <a href=\"http://www.gnu.org/copyleft/fdl.html\">GNU Free Documentation License</a>, Version 1.2 or any later version published by the <a href=\"http://www.fsf.org/\">Free Software Foundation</a>; with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.",
   "rights_1"=>"Document protected by a login/password.",
   "rights_2"=>"Private document.",
   "rights_3"=>"Confidential document.",
   "meta_description"=>"%s (no detailed description)",
   "meta_copyright"=>"Copyleft &copy; %s %s",
   "page_generated_by_uwikicms"=>"Page generated by <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> %s on %s.",
   "xul_generated_by_uwikicms"=>"XUL interface generated by UWiKiCMS %s on %s.",
   "last_update"=>"Updated on %s.",
   "source"=>"Source:",
   "action_root"=>"Home",
   "action_login"=>"Login",
   "action_logout"=>"Logout (%s)",
   "action_view"=>"View page",
   "action_rss"=>"RSS feed",
   "action_tree"=>"Site map",
   "action_css_yes"=>"With CSS",
   "action_css_no"=>"Without CSS",
   "action_update"=>"Modify",
   "action_delete"=>"Delete",
   "action_new"=>"New page",
   "action_imagenew"=>"New image",
   "action_clearcache"=>"Clear cache",
   "action_renum"=>"Renum",
   "action_help"=>"Help",
   "action_allinone"=>"All in one page",
   "action_gallery"=>"Gallery (Mozilla/Firefox)",
   "login_user"=>"User",
   "login_password"=>"Password",
   "login_connect"=>"Connect",
   "logout_success"=>"You have been disconnected.",
   "403_forbidden"=>"HTTP error 403: you are not allowed to view this document.",
   "404_not_found"=>"HTTP error 404: the document you requested was not found.",
   "continue"=>"Continue",
   "view_lang_en"=>"English",
   "view_lang_fr"=>"Fran&ccedil;ais",
   "view_lang_de"=>"Deutsch",
   "view_lang_es"=>"Espaol",
   "view_lang_da"=>"Danish",
   "translate"=>"Translate:",
   "home"=>"Home: %s",
   "up"=>"Up: %s",
   "next"=>"Next: %s",
   "prev"=>"Prev: %s",
   "this_is_a_tree"=>"Site map of \"%s\"",
   "this_is_a_subtree"=>"Map of \"%s\"",
   "all_in_one_site"=>"All contents of \"%s\" on %s",
   "all_in_one_subsite"=>"All contents of section \"%s\" on %s",
   "display_status_0"=>"Only public content is displayed.",
   "display_status_1"=>"Public and password protected contents are displayed.",
   "display_status_2"=>"Public, password protected and private contents are displayed.",
   "display_status_3"=>"All contents (public, password protected, private, confidential) are displayed.",
   "alt"=>"Title",
   "longdesc"=>"Description",
   "imagefile"=>"Image file",
   "filename_width_height_size"=>"%s - %d&nbsp;x&nbsp;%d - %sb",
   "current_image"=>"Current image",
   "allinone_status"=>"Display documents matching this status only",
   "allinone_intro"=>"Introduction text",
   "allinone_max_size"=>"Images max size (pixels)",
   "gallery_title"=>"XUL Gallery",
   "gallery_prev"=>"Previous image",
   "gallery_next"=>"Next image",
   "gallery_empty"=>"No images in this gallery",
   "google_search"=>"Google search",
   "rss_about"=>"RSS feed for %s",
   "do_date_update"=>"Update last modification date",

   "" => ""

   );

?>